@@ -525,7 +525,8 @@ class Batch(BaseDeployment):
                 deployment_name: str,
                 meta_props: Dict,
                 serving_name=None, # Not used, but added to match unified parameters for _deploy
-                result_client=None) -> Dict:
+                result_client=None,
+                hardware_spec=None) -> Dict: # Not used, but added to match unified parameters for _deploy
         """
         Deploy model into WML.
 
