@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 import json
 from ibm_watson_machine_learning.utils import DEPLOYMENT_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, print_text_header_h1, print_text_header_h2, STR_TYPE, STR_TYPE_NAME, docstring_parameter, str_type_conv, \
     StatusLogger, meta_props_str_conv, convert_metadata_to_parameters
@@ -40,7 +40,6 @@ class Deployments(WMLResource):
         if not client.ICP and not client.CLOUD_PLATFORM_SPACES and not client.ICP_PLATFORM_SPACES:
             Deployments._validate_type(client.service_instance.details, u'instance_details', dict, True)
             Deployments._validate_type_of_details(client.service_instance.details, INSTANCE_DETAILS_TYPE)
-        self.session = requests.Session()
         self._ICP = client.ICP
         if client.CLOUD_PLATFORM_SPACES or client.ICP_PLATFORM_SPACES:
             self.ConfigurationMetaNames = DeploymentNewMetaNames()
@@ -214,14 +213,12 @@ class Deployments(WMLResource):
                         url,
                         json=metaProps,
                         params=self._client._params(),  # version is mandatory
-                        headers=self._client._get_headers(),
-                        verify=False)
+                        headers=self._client._get_headers())
                 else:
                     response = requests.post(
                         url,
                         json=metaProps,
-                        headers=self._client._get_headers(),
-                        verify=False)
+                        headers=self._client._get_headers())
 
             ## Post Deployment call executed
             if response.status_code == 202:
@@ -245,7 +242,7 @@ class Deployments(WMLResource):
                 with StatusLogger(status) as status_logger:
                     while True:
                         time.sleep(5)
-                        deployment_details = self._client.deployments.get_details(deployment_uid)
+                        deployment_details = self._client.deployments.get_details(deployment_uid, _silent=True)
                         #this is wrong , needs to update for ICP
                         if "system" in deployment_details:
                             notification = deployment_details['system']['warnings'][0]['message']
@@ -411,8 +408,7 @@ class Deployments(WMLResource):
         url = self._client.service_instance._href_definitions.get_deployments_href()
         res = requests.get(url,
                            headers=self._client._get_headers(),
-                           params=params,
-                           verify=not self._client.ICP)
+                           params=params)
 
         if res.status_code == 409:
             response = res.json()
@@ -448,7 +444,7 @@ class Deployments(WMLResource):
         return status_code != 409
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def get_details(self, deployment_uid=None, serving_name=None, limit=None, asynchronous=False, get_all=False):
+    def get_details(self, deployment_uid=None, serving_name=None, limit=None, asynchronous=False, get_all=False, _silent=False):
         """
            Get information about your deployment(s). If deployment_uid is not passed, all deployment details are fetched.
 
@@ -511,7 +507,7 @@ class Deployments(WMLResource):
         else:
             deployment_details = self._get_artifact_details(url, deployment_uid, limit, 'deployments', query_params=query_params)
 
-        if "system" in deployment_details:
+        if "system" in deployment_details and not _silent:
             print("Note: " + deployment_details['system']['warnings'][0]['message'])
 
         return deployment_details
@@ -646,15 +642,13 @@ class Deployments(WMLResource):
                 response_delete = requests.delete(
                     deployment_url,
                     params=self._client._params(),
-                    headers=self._client._get_headers(),
-                    verify=False)
+                    headers=self._client._get_headers())
             else:
                 response_delete = requests.delete(
                     deployment_url,
                     #TODO:  The below line needs to uncommeted after /v4/deployment accespts query param
                    # params=self._client._params(),
-                    headers=self._client._get_headers(),
-                    verify=False)
+                    headers=self._client._get_headers())
 
         return self._handle_response(204, u'deployment deletion', response_delete, False)
 
@@ -764,13 +758,13 @@ class Deployments(WMLResource):
             if self._client.CLOUD_PLATFORM_SPACES:
                 params = self._client._params()
                 del params[u'space_id']
-                response_scoring = self.session.post(
+                response_scoring = requests.post(
                     scoring_url,
                     json=payload,
                     params=params,  # version parameter is mandatory
                     headers=headers)
             else:
-                response_scoring = self.session.post(
+                response_scoring = requests.post(
                     scoring_url,
                     json=payload,
                     headers=headers)
@@ -778,18 +772,16 @@ class Deployments(WMLResource):
             if self._client.ICP_PLATFORM_SPACES:
                 params = self._client._params()
                 del params[u'space_id']
-                response_scoring = self.session.post(
+                response_scoring = requests.post(
                     scoring_url,
                     json=payload,
                     params=params,  # version parameter is mandatory
-                    headers=headers,
-                    verify=False)
+                    headers=headers)
             else:
-                response_scoring = self.session.post(
+                response_scoring = requests.post(
                     scoring_url,
                     json=payload,
-                    headers=headers,
-                    verify=False)
+                    headers=headers)
 
         return self._handle_response(200, u'scoring', response_scoring)
 
@@ -869,26 +861,11 @@ class Deployments(WMLResource):
         if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40:
             download_url = download_url + "&version=" + self._client.version_param
             params = None
-        if not self._ICP:
-            # if self._client.CLOUD_PLATFORM_SPACES:
-            #     download_url = download_url + "&version=" + self._client.version_param
-            #     response = requests.get(
-            #         download_url,
-            #         headers=self._client._get_headers()
-            #     )
-            # else:
-            response = requests.get(
-                    download_url,
-                    params=params,
-                    headers=self._client._get_headers()
-                )
-        else:
-            response = requests.get(
-                download_url,
-                params=params,
-                headers=self._client._get_headers(),
-                verify=False
-            )
+        response = requests.get(
+            download_url,
+            params=params,
+            headers=self._client._get_headers()
+        )
         if filename is None:
             filename = 'mlartifact.tar.gz'
 
@@ -904,71 +881,6 @@ class Deployments(WMLResource):
         else:
             raise WMLClientError(u'Unable to download deployment content: ' + response.text)
 
-    # @docstring_parameter({'str_type': STR_TYPE_NAME})
-    # def score(self, deployment_id, meta_props, transaction_id=None):
-    #         """
-    #             Make scoring requests against deployed artifact.
-    #
-    #             **Parameters**
-    #
-    #             .. important::
-    #                 #. **deployment_id**:  UID of the deployment to be scored\n
-    #                    **type**: str\n
-    #                 #. **meta_props**:  Meta props for scoring\n
-    #                                     >>> Use client.deployments.ScoringMetaNames.show() to view the list of ScoringMetaNames.
-    #                    **type**: dict\n
-    #                 #. **transaction_id**:  transaction id to be passed with records during payload logging (optional)\n
-    #                    **type**: str\n
-    #
-    #             **Output**
-    #
-    #             .. important::
-    #                 **returns**: scoring result containing prediction and probability\n
-    #                 **return type**: dict\n
-    #
-    #             .. note::
-    #
-    #                     * client.deployments.ScoringMetaNames.SCORING_INPUT_DATA is the only metaname valid for sync scoring.\n
-    #
-    #             **Example**
-    #
-    #              >>> scoring_payload = {wml_client.deployments.ScoringMetaNames.INPUT_DATA: [{'fields': ['GENDER','AGE','MARITAL_STATUS','PROFESSION'], 'values': [['M',23,'Single','Student'],['M',55,'Single','Executive']]}]}
-    #              >>> predictions = client.deployments.score(deployment_id, scoring_payload)
-    #              >>> predictions = client.deployments.score(deployment_id, scoring_payload,async=True)
-    #         """
-    #         Deployments._validate_type(deployment_id, u'scoring_url', STR_TYPE, True)
-    #         Deployments._validate_type(meta_props, u'meta_props', dict, True)
-    #
-    #
-    #         score_payload = {}
-    #         if meta_props[self.ScoringMetaNames.INPUT_DATA] is None:
-    #             raise WMLClientError("Scoring data input is mandatory for synchronous scoring")
-    #
-    #         score_payload["input_data"] = meta_props[self.ScoringMetaNames.INPUT_DATA]
-    #         payload = score_payload
-    #         Deployments._validate_type(deployment_id, u'scoring_url', STR_TYPE, True)
-    #         Deployments._validate_type(payload, u'payload', dict, True)
-    #
-    #         headers = self._client._get_headers()
-    #
-    #         if transaction_id is not None:
-    #             headers.update({'x-global-transaction-id': transaction_id})
-    #         # making change - connection keep alive
-    #         scoring_url = self._wml_credentials["url"] + "/v4/deployments/"+deployment_id+"/predictions"
-    #         if not self._ICP:
-    #             response_scoring = self.session.post(
-    #                 scoring_url,
-    #                 json=payload,
-    #                 headers=headers)
-    #         else:
-    #             response_scoring = self.session.post(
-    #                 scoring_url,
-    #                 json=payload,
-    #                 headers=headers,
-    #                 verify=False)
-    #
-    #         return self._handle_response(200, u'scoring', response_scoring)
-
     def list(self, limit=None):
         """
            List deployments. If limit is set to None there will be only first 50 records shown.
@@ -1184,7 +1096,7 @@ class Deployments(WMLResource):
         if not self._ICP:
             response = requests.patch(url, json=patch_payload, params=self._client._params(), headers=self._client._get_headers())
         else:
-            response = requests.patch(url, json=patch_payload, params=self._client._params(), headers=self._client._get_headers(), verify=False)
+            response = requests.patch(url, json=patch_payload, params=self._client._params(), headers=self._client._get_headers())
 
         if patch_job and response.status_code == 202:
             updated_details = self._handle_response(202, u'deployment asset patch', response)
@@ -1260,23 +1172,15 @@ class Deployments(WMLResource):
                 raise TypeError("`retention` takes integer values greater or equal than -1.")
             params.update({'retention': retention})
 
-        if not self._ICP:
-            response_scoring = self.session.post(
-                scoring_url,
-                params=params,
-                json=scoring_payload,
-                headers=headers)
-        else:
-            response_scoring = self.session.post(
-                scoring_url,
-                params = params,
-                json=scoring_payload,
-                headers=headers,
-                verify=False)
+        response_scoring = requests.post(
+            scoring_url,
+            params=params,
+            json=scoring_payload,
+            headers=headers)
 
         return self._handle_response(202, u'scoring asynchronously', response_scoring)
 
-    def create_job(self, deployment_id, meta_props, retention=None, transaction_id=None):
+    def create_job(self, deployment_id, meta_props, retention=None, transaction_id=None, _asset_id=None):
         """
             Create an asynchronous deployment job.
 
@@ -1318,14 +1222,17 @@ class Deployments(WMLResource):
         Deployments._validate_type(deployment_id, u'deployment_uid', STR_TYPE, True)
         Deployments._validate_type(meta_props, u'meta_props', dict, True)
 
-        scoring_data = None
-        flag = 0 ## To see if it is async scoring or DecisionOptimization Job
-        deployment_details = self.get_details(deployment_id)
-
-        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
-            asset = deployment_details["entity"]["asset"]['id']
+        if _asset_id:
+            Deployments._validate_type(_asset_id, u'_asset_id', STR_TYPE, True)
+            # We assume that _asset_id is the id of the asset that was deployed
+            # in the deployment with id deployment_id, and we save one REST call
+            asset = _asset_id
         else:
-            asset = deployment_details["entity"]["asset"]["href"].split("/")[-1]
+            deployment_details = self.get_details(deployment_id)
+            if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
+                asset = deployment_details["entity"]["asset"]['id']
+            else:
+                asset = deployment_details["entity"]["asset"]["href"].split("/")[-1]
 
         do_model = False
         if self._client.ICP_30 or self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
@@ -1339,6 +1246,7 @@ class Deployments(WMLResource):
                 if "do" in asset_details["entity"]["type"]:
                     do_model = True
 
+        flag = 0 ## To see if it is async scoring or DecisionOptimization Job
         if do_model:
             payload = self.DecisionOptimizationMetaNames._generate_resource_metadata(meta_props,
                                                                                      with_validation=True,
@@ -1348,6 +1256,7 @@ class Deployments(WMLResource):
             payload = self.ScoringMetaNames._generate_resource_metadata(meta_props, with_validation=True,
                                                                         client=self._client)
 
+        scoring_data = None
         if "scoring" in payload and "input_data" in payload["scoring"]:
                 scoring_data = payload["scoring"]["input_data"]
 
@@ -1629,17 +1538,10 @@ class Deployments(WMLResource):
         if hard_delete is True:
             params.update({'hard_delete': u'true'})
 
-        if not self._ICP:
-            response_delete = requests.delete(
-                url,
-                headers=self._client._get_headers(),
-                params=params)
-        else:
-            response_delete = requests.delete(
-                url,
-                headers=self._client._get_headers(),
-                params=params,
-                verify=False)
+        response_delete = requests.delete(
+            url,
+            headers=self._client._get_headers(),
+            params=params)
 
         return self._handle_response(204, u'deployment async job deletion', response_delete, False)
 
@@ -1680,7 +1582,7 @@ class Deployments(WMLResource):
     #
     #     else:
     #         response_post = requests.post(url, json=metadata,
-    #                                       headers=self._client._get_headers(), verify=False)
+    #                                       headers=self._client._get_headers())
     #
     #     return self._handle_response(201, u'deployment job deletion', response_post, False)
     #
