@@ -12,7 +12,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 import json
 import base64
 import logging
@@ -334,8 +334,7 @@ class ServiceInstanceNewPlan:
                                  headers={
                                      'Content-Type': 'application/json'
                                  },
-                                 data=self._get_cpd_auth_pair(),
-                                 verify=False)
+                                 data=self._get_cpd_auth_pair())
 
         if response.status_code == 200:
             self._expiration_datetime = None
@@ -349,8 +348,7 @@ class ServiceInstanceNewPlan:
                                  headers={
                                      'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8'
                                  },
-                                 data=self._get_cpd_bedrock_auth_data(),
-                                 verify=False)
+                                 data=self._get_cpd_bedrock_auth_data())
 
         if response.status_code != 200:
             raise WMLClientError(u'Error refreshing the token.', response, logg_messages=False)
@@ -364,8 +362,7 @@ class ServiceInstanceNewPlan:
                                 headers={
                                     'username': 'admin',
                                     'iam-token': iam_token
-                                },
-                                verify=False)
+                                })
 
         if response.status_code == 200:
             return response.json()['accessToken']
