@@ -39,23 +39,23 @@ def process_heartbeat(client, **kwargs):
         hearbeat_resp_json = json.loads(hearbeat_resp.content.decode("utf-8"))
         service_version = hearbeat_resp_json.get("service_implementation")
 
-        if service_version.startswith("4.0.4.") or service_version.startswith("4.0.3."):
-            return "cpd403"
         if service_version.startswith("4.0"):
             version_details = service_version.split('-')
-            if version_details[1] >= "202108":
+            if version_details[1] >= "202110":
+                return "general"
+            elif version_details[1] >= "202108":
                 return "cpd402"
             else:
                 return "cpd401"
         if service_version.startswith("35"):
             return "cpd35"
 
-        return "cloud"
+        return "general"
 
     except Exception as ex:
         logger.info("unable to process heartbeat")
         logger.exception(ex)
-        return "cloud"
+        return "general"
 
 
 def import_source(module_file_path):
@@ -79,11 +79,10 @@ class Party(WMLResource):
     """
 
     SUPPORTED_PLATFORMS_MAP = {
-        'cloud': "/cloud/ibmfl/__init__.py",
+        'general': "/cloud/ibmfl/__init__.py",
         'cpd35': "/cpd35/ibmfl/__init__.py",
         'cpd401': "1.0.122",
-        'cpd402': "1.0.165",
-        'cpd403': "/cpd403/ibmfl/__init__.py",
+        'cpd402': "1.0.165"
     }
 
     def __init__(self, client=None, **kwargs):
