@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE,PKG_EXTN_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
 from ibm_watson_machine_learning.metanames import PkgExtnMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
@@ -63,7 +63,7 @@ class PkgExtn(WMLResource):
                                     headers=self._client._get_headers())
         else:
             response = requests.get(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
-                                      headers=self._client._get_headers(), verify=False)
+                                      headers=self._client._get_headers())
         if response.status_code == 200:
             return self._get_required_element_from_response(self._handle_response(200, u'get hw spec details', response))
         else:
@@ -124,7 +124,7 @@ class PkgExtn(WMLResource):
         if not self._ICP:
             creation_response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), data=pkg_extn_meta_json)
         else:
-            creation_response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), data=pkg_extn_meta_json, verify=False)
+            creation_response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), data=pkg_extn_meta_json)
 
         pkg_extn_details = self._handle_response(201, u'creating new package_extensions', creation_response)
 
@@ -141,24 +141,15 @@ class PkgExtn(WMLResource):
             else:
                 put_response = requests.put(
                     self._wml_credentials['url'] + pkg_extn_presigned_url,
-                    files=f,
-                    verify=False
+                    files=f
                 )
             if put_response.status_code == 201 or put_response.status_code == 200:
                 # Step3: Mark the upload complete
-                if not self._ICP:
-                    complete_response = requests.post(
-                        self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_asset_id) + "/upload_complete",
-                        headers=self._client._get_headers(),
-                        params=self._client._params()
-                    )
-                else:
-                    complete_response = requests.post(
-                        self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_asset_id) + "/upload_complete",
-                        headers=self._client._get_headers(),
-                        params=self._client._params(),
-                        verify=False
-                    )
+                complete_response = requests.post(
+                    self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_asset_id) + "/upload_complete",
+                    headers=self._client._get_headers(),
+                    params=self._client._params()
+                )
                 if complete_response.status_code == 204:
                     print("SUCCESS")
                     return self._get_required_element_from_response(pkg_extn_details)
@@ -193,7 +184,7 @@ class PkgExtn(WMLResource):
         if not self._ICP:
             response = requests.get(href, params=self._client._params(), headers=self._client._get_headers())
         else:
-            response = requests.get(href, params=self._client._params(), headers=self._client._get_headers(), verify=False)
+            response = requests.get(href, params=self._client._params(), headers=self._client._get_headers())
         self._handle_response(200, u'list pkg_extn', response)
         asset_details = self._handle_response(200, u'list assets', response)["resources"]
         pkg_extn_values = [
@@ -304,7 +295,7 @@ class PkgExtn(WMLResource):
 
             response = requests.get(self._client.service_instance._href_definitions.get_pkg_extns_href(),
                                     params=parameters,
-                                    headers=self._client._get_headers(), verify=False)
+                                    headers=self._client._get_headers())
         if response.status_code == 200:
             total_values = self._handle_response(200, u'get pkg extn', response)["total_results"]
             if total_values != 0:
@@ -402,7 +393,7 @@ class PkgExtn(WMLResource):
                                     headers=self._client._get_headers())
         else:
             response = requests.delete(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
-                                      headers=self._client._get_headers(), verify=False)
+                                      headers=self._client._get_headers())
         if response.status_code == 200:
             return self._get_required_element_from_response(response.json())
         else:
@@ -417,7 +408,7 @@ class PkgExtn(WMLResource):
                                        headers=self._client._get_headers())
         else:
             response = requests.delete(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
-                                       headers=self._client._get_headers(), verify=False)
+                                       headers=self._client._get_headers())
 
     def _get_required_element_from_response(self, response_data):
 
@@ -505,7 +496,7 @@ class PkgExtn(WMLResource):
             artifact_content_url = pkg_extn_details['entity']['package_extension']['href']
 
             r = requests.get(artifact_content_url, params=self._client._params(), headers=self._client._get_headers(),
-                             stream=True, verify=False)
+                             stream=True)
             if r.status_code != 200:
                 raise ApiRequestFailure(u'Failure during {}.'.format("downloading model"), r)
 
@@ -518,15 +509,9 @@ class PkgExtn(WMLResource):
             except IOError as e:
                 raise WMLClientError(u'Saving asset with artifact_url: \'{}\' failed.'.format(filename), e)
         else:
-            if not self._ICP:
-                pkg_extn_response = requests.get(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_id),
-                                          params=self._client._params(),
-                                          headers=self._client._get_headers())
-            else:
-                pkg_extn_response = requests.get(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_id),
-                                                 params=self._client._params(),
-                                                 headers=self._client._get_headers(),
-                                                 verify=False)
+            pkg_extn_response = requests.get(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_id),
+                                      params=self._client._params(),
+                                      headers=self._client._get_headers())
 
             pkg_extn_details = self._handle_response(200, u'get assets', pkg_extn_response)
 
@@ -537,8 +522,7 @@ class PkgExtn(WMLResource):
                     # att_response = requests.get(self._wml_credentials["url"]+artifact_content_url)
                     att_response = requests.get(artifact_content_url)
                 else:
-                    att_response = requests.get(self._wml_credentials["url"]+artifact_content_url,
-                                            verify=False)
+                    att_response = requests.get(self._wml_credentials["url"]+artifact_content_url)
 
                 if att_response.status_code != 200:
                     raise ApiRequestFailure(u'Failure during {}.'.format("downloading package extension"),
