@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 from ibm_watson_machine_learning.utils import STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv
 from ibm_watson_machine_learning.metanames import RemoteTrainingSystemMetaNames
 from ibm_watson_machine_learning.party_wrapper import Party
@@ -81,17 +81,10 @@ class RemoteTrainingSystem(WMLResource):
 
         href = self._client.service_instance._href_definitions.remote_training_systems_href()
 
-        if not self._ICP:
-            creation_response = requests.post(href,
-                                              params=self._client._params(),
-                                              headers=self._client._get_headers(),
-                                              json=meta)
-        else:
-            creation_response = requests.post(href,
-                                              params=self._client._params(),
-                                              headers=self._client._get_headers(),
-                                              json=meta,
-                                              verify=False)
+        creation_response = requests.post(href,
+                                          params=self._client._params(),
+                                          headers=self._client._get_headers(),
+                                          json=meta)
 
         details = self._handle_response(expected_status_code=201,
                                         operationName=u'store remote training system specification',
@@ -143,15 +136,9 @@ class RemoteTrainingSystem(WMLResource):
 
         href = self._client.service_instance._href_definitions.remote_training_system_href(remote_training_systems_id)
 
-        if not self._ICP:
-            delete_response = requests.delete(href,
-                                              params=self._client._params(),
-                                              headers=self._client._get_headers())
-        else:
-            delete_response = requests.delete(href,
-                                              params=self._client._params(),
-                                              headers=self._client._get_headers(),
-                                              verify=False)
+        delete_response = requests.delete(href,
+                                          params=self._client._params(),
+                                          headers=self._client._get_headers())
 
         details = self._handle_response(expected_status_code=204,
                                         operationName=u'delete remote training system definition',
@@ -314,17 +301,10 @@ class RemoteTrainingSystem(WMLResource):
 
         href = self._client.service_instance._href_definitions.remote_training_system_href(remote_training_system_id)
 
-        if not self._ICP:
-            response = requests.patch(href,
-                                      json=patch_payload,
-                                      params = self._client._params(),
-                                      headers=self._client._get_headers())
-        else:
-            response = requests.patch(href,
-                                      json=patch_payload,
-                                      params = self._client._params(),
-                                      headers=self._client._get_headers(),
-                                      verify=False)
+        response = requests.patch(href,
+                                  json=patch_payload,
+                                  params = self._client._params(),
+                                  headers=self._client._get_headers())
 
         updated_details = self._handle_response(200, u'remote training system patch', response)
 
