@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE,DATA_ASSETS_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
 from ibm_watson_machine_learning.metanames import ScriptMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
@@ -65,7 +65,7 @@ class Script(WMLResource):
                                     headers=self._client._get_headers())
         else:
             response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(script_uid), params=self._client._params(),
-                                      headers=self._client._get_headers(), verify=False)
+                                      headers=self._client._get_headers())
         if response.status_code == 200:
             response = self._get_required_element_from_response(self._handle_response(200, u'get asset details', response))
 
@@ -361,24 +361,21 @@ class Script(WMLResource):
                         self._client.service_instance._href_definitions.get_data_assets_href(),
                         headers=self._client._get_headers(),
                         json=asset_meta,
-                        params=self._client._params(),
-                        verify=False
+                        params=self._client._params()
                     )
                 else:
                     asset_type_response = requests.post(
                         self._client.service_instance._href_definitions.get_wsd_asset_type_href() + '?',
                         headers=self._client._get_headers(),
                         json=base_script_asset,
-                        params=self._client._params(),
-                        verify=False
+                        params=self._client._params()
                     )
                     if asset_type_response.status_code == 201 or asset_type_response.status_code == 409:
                         creation_response = requests.post(
                             self._client.service_instance._href_definitions.get_data_assets_href(),
                             headers=self._client._get_headers(),
                             json=asset_meta,
-                            params=self._client._params(),
-                            verify=False
+                            params=self._client._params()
                         )
 
             asset_details = self._handle_response(201, u'creating new asset', creation_response)
@@ -390,21 +387,12 @@ class Script(WMLResource):
                         "name": "attachment_"+asset_id
                     }
 
-                if not self._ICP:
-                    attachment_response = requests.post(
-                        self._client.service_instance._href_definitions.get_attachments_href(asset_id),
-                        headers=self._client._get_headers(),
-                        params=self._client._params(),
-                        json=attachment_meta
-                    )
-                else:
-                    attachment_response = requests.post(
-                        self._client.service_instance._href_definitions.get_attachments_href(asset_id),
-                        headers=self._client._get_headers(),
-                        json=attachment_meta,
-                        params=self._client._params(),
-                        verify=False
-                    )
+                attachment_response = requests.post(
+                    self._client.service_instance._href_definitions.get_attachments_href(asset_id),
+                    headers=self._client._get_headers(),
+                    params=self._client._params(),
+                    json=attachment_meta
+                )
                 attachment_details = self._handle_response(201, u'creating new attachment', attachment_response)
                 if attachment_response.status_code == 201:
                     attachment_id = attachment_details["attachment_id"]
@@ -423,8 +411,7 @@ class Script(WMLResource):
                     else:
                         put_response = requests.put(
                             self._wml_credentials['url'] + attachment_url,
-                            files=f,
-                            verify=False
+                            files=f
                         )
                     if put_response.status_code == 201 or put_response.status_code == 200:
                         # Step4: Complete attachment
@@ -440,8 +427,7 @@ class Script(WMLResource):
                             complete_response = requests.post(
                                 self._client.service_instance._href_definitions.get_attachment_href(asset_id,attachment_id)+"/complete",
                                 headers=self._client._get_headers(),
-                                params=self._client._params(),
-                                verify=False
+                                params=self._client._params()
                             )
                         if complete_response.status_code == 200:
                             print("SUCCESS")
@@ -492,7 +478,7 @@ class Script(WMLResource):
         if not self._ICP:
             response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(),json=data)
         else:
-            response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(),json=data, verify=False)
+            response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(),json=data)
         self._handle_response(200, u'list assets', response)
         asset_details = self._handle_response(200, u'list assets', response)["results"]
         space_values = [
@@ -549,7 +535,7 @@ class Script(WMLResource):
         else:
             asset_response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid),
                                           params=params,
-                                          headers=self._client._get_headers(), verify=False)
+                                          headers=self._client._get_headers())
         asset_details = self._handle_response(200, u'get assets', asset_response)
 
         if self._WSD:
@@ -558,7 +544,7 @@ class Script(WMLResource):
                                    urllib.parse.quote('script/' + attachment_url, safe='')
 
             r = requests.get(artifact_content_url, params=self._client._params(), headers=self._client._get_headers(),
-                             stream=True, verify=False)
+                             stream=True)
             if r.status_code != 200:
                 raise ApiRequestFailure(u'Failure during {}.'.format("downloading data asset"), r)
 
@@ -577,21 +563,16 @@ class Script(WMLResource):
                                         headers=self._client._get_headers())
             else:
                 response = requests.get(self._client.service_instance._href_definitions.get_attachment_href(asset_uid,attachment_id), params=params,
-                                          headers=self._client._get_headers(), verify=False)
+                                          headers=self._client._get_headers())
             if response.status_code == 200:
                 attachment_signed_url = response.json()["url"]
                 if 'connection_id' in asset_details["attachments"][0]:
-                    if not self._ICP:
-                        att_response = requests.get(attachment_signed_url)
-                    else:
-                        att_response = requests.get(attachment_signed_url,
-                                                    verify=False)
+                    att_response = requests.get(attachment_signed_url)
                 else:
                     if not self._ICP:
                         att_response = requests.get(attachment_signed_url)
                     else:
-                        att_response = requests.get(self._wml_credentials["url"]+attachment_signed_url,
-                                                verify=False)
+                        att_response = requests.get(self._wml_credentials["url"]+attachment_signed_url)
                 if att_response.status_code != 200:
                     raise ApiRequestFailure(u'Failure during {}.'.format("downloading asset"), att_response)
 
@@ -745,19 +726,11 @@ class Script(WMLResource):
         # STEP 4. Get the updated script record and return
 
         # STEP 1
-        if not self._ICP:
-            response = requests.get(
-                url,
-                params=self._client._params(),
-                headers=self._client._get_headers()
-            )
-        else:
-            response = requests.get(
-                url,
-                params=self._client._params(),
-                headers=self._client._get_headers(),
-                verify=False
-            )
+        response = requests.get(
+            url,
+            params=self._client._params(),
+            headers=self._client._get_headers()
+        )
 
         if response.status_code != 200:
             if response.status_code == 404:
@@ -813,7 +786,7 @@ class Script(WMLResource):
                     response_patch = requests.patch(meta_patch_url,
                                                     json=meta_patch_payload,
                                                     params=self._client._params(),
-                                                    headers=self._client._get_headers(),verify=False)
+                                                    headers=self._client._get_headers())
 
                 updated_details = self._handle_response(200, u'script patch', response_patch)
 
@@ -829,7 +802,7 @@ class Script(WMLResource):
                     response_patch = requests.patch(entity_patch_url,
                                                     json=entity_patch_payload,
                                                     params=self._client._params(),
-                                                    headers=self._client._get_headers(), verify=False)
+                                                    headers=self._client._get_headers())
 
                 updated_details = self._handle_response(200, u'script patch', response_patch)
 
@@ -851,19 +824,11 @@ class Script(WMLResource):
         # Have to fetch again to reflect updated asset and attachment ids
         url = self._client.service_instance._href_definitions.get_asset_href(script_uid)
 
-        if not self._ICP:
-            response = requests.get(
-                url,
-                params=self._client._params(),
-                headers=self._client._get_headers()
-            )
-        else:
-            response = requests.get(
-                url,
-                params=self._client._params(),
-                headers=self._client._get_headers(),
-                verify=False
-            )
+        response = requests.get(
+            url,
+            params=self._client._params(),
+            headers=self._client._get_headers()
+        )
 
         if response.status_code != 200:
             if response.status_code == 404:
@@ -935,7 +900,7 @@ class Script(WMLResource):
                                     headers=self._client._get_headers())
         else:
             response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
-                                      headers=self._client._get_headers(), verify=False)
+                                      headers=self._client._get_headers())
         if response.status_code == 200:
             return self._get_required_element_from_response(response.json())
         else:
@@ -1132,7 +1097,7 @@ class Script(WMLResource):
                                        headers=self._client._get_headers())
         else:
             response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
-                                       headers=self._client._get_headers(), verify=False)
+                                       headers=self._client._get_headers())
 
     def _get_required_element_from_response(self, response_data):
 
