@@ -1220,10 +1220,6 @@ def check_dependencies_versions(request_json: dict, wml_client, estimator_pkg: s
                         elif numpy_installed_version.minor != numpy_sw_spec_version.minor:
                             errored_packages.append(package)
 
-                    elif package['name'] == 'snapml' and version.parse(installed_module_version) >= version.parse('1.8'):
-                        package['version'] = f"<1.8.0 and >={package['version']}"
-                        errored_packages.append(package)
-
                     elif version.parse(installed_module_version) < version.parse(package['version']):
                         # we should produce different error for lale and snap_ml as only 2 major numbers are significant
                         packages_less_strict_error_list = ['lale', 'snapml']
